@@ -1,6 +1,8 @@
-from torchyolo.automodel import AutoDetectionModel
 from typing import Optional
 
+from torchyolo.automodel import AutoDetectionModel
+
+
 class YoloPredictor:
     def __init__(
         self,
@@ -43,12 +45,8 @@ class YoloPredictor:
 
 if __name__ == "__main__":
     predictor = YoloPredictor(
-        model_type="yolox", 
-        model_path="yolox_s.pth", 
-        config_path = "configs.yolox.yolox_s",
-        device="cpu", 
-        image_size=640
+        model_type="yolov8", model_path="yolov8n.pt", device="cpu", image_size=640
     )
-    
+
     image = "data/highway.jpg"
     result = predictor.predict(image)
